"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.24.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.datasets_api import DatasetsApi  # noqa: E501


class TestDatasetsApi(unittest.TestCase):
    """DatasetsApi unit test stubs"""

    def setUp(self):
        self.api = DatasetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_datasets_id(self):
        """Test case for delete_datasets_id

        Remove Dataset with given ID  # noqa: E501
        """
        pass

    def test_get_datasets(self):
        """Test case for get_datasets

        Retrieve a list of datasets  # noqa: E501
        """
        pass

    def test_get_datasets_id(self):
        """Test case for get_datasets_id

        Retrieve a Dataset with the given ID  # noqa: E501
        """
        pass

    def test_patch_datasets_id(self):
        """Test case for patch_datasets_id

        Updates the provided fields of Dataset with given ID  # noqa: E501
        """
        pass

    def test_post_datasets(self):
        """Test case for post_datasets

        Create a new Dataset  # noqa: E501
        """
        pass

    def test_put_datasets_id(self):
        """Test case for put_datasets_id

        Updates Dataset with given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
