"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.24.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import kdp_api
from kdp_api.model.segment_list import SegmentList
globals()['SegmentList'] = SegmentList
from kdp_api.model.segment_paginator import SegmentPaginator


class TestSegmentPaginator(unittest.TestCase):
    """SegmentPaginator unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSegmentPaginator(self):
        """Test SegmentPaginator"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SegmentPaginator()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
