"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.24.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.indexes_api import IndexesApi  # noqa: E501


class TestIndexesApi(unittest.TestCase):
    """IndexesApi unit test stubs"""

    def setUp(self):
        self.api = IndexesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_indexes_id(self):
        """Test case for delete_indexes_id

        Removes Index with the given ID  # noqa: E501
        """
        pass

    def test_get_indexes(self):
        """Test case for get_indexes

        Retrieve list of Indexes  # noqa: E501
        """
        pass

    def test_get_indexes_id(self):
        """Test case for get_indexes_id

        Retrieve Index with given ID  # noqa: E501
        """
        pass

    def test_patch_indexes_id(self):
        """Test case for patch_indexes_id

        Updates fields provided for Index with the ID given  # noqa: E501
        """
        pass

    def test_post_indexes(self):
        """Test case for post_indexes

        Create a new Index  # noqa: E501
        """
        pass

    def test_put_indexes_id(self):
        """Test case for put_indexes_id

        Updates Index with given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
